package com.atosworldline.asccend.gui.db;

import java.sql.Connection;
import java.sql.DriverManager;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.sql.Statement;
import java.util.UUID;

import javax.sql.DataSource;

import org.apache.commons.lang3.StringUtils;
import org.junit.After;
import org.junit.Before;
import org.junit.Test;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import com.mchange.v2.c3p0.ComboPooledDataSource;

public class TestTeiidTransaction {
	
	private final static Logger logger = LoggerFactory.getLogger(TestTeiidTransaction.class);
	
	public Connection getConnection() throws Exception {
		Class.forName("org.teiid.jdbc.TeiidDriver");
		return DriverManager.getConnection("jdbc:teiid:testvdb@mm://an-win764-vm:31000;", "user", "user");
	}
	
	@Before
	public void setUp() {
	}
	
	@After
	public void tearDown() {
		
	}
	
	@Test
	public void testRollback() throws Exception {
		Connection conn = getConnection();
		conn.setAutoCommit(false);
		
		String value = UUID.randomUUID().toString().substring(0, 30);
		String sql = "UPDATE customer SET cust_name=? WHERE cust_nbr=0";
		
		PreparedStatement ps = conn.prepareStatement(sql);
		ps.setString(1, value);
		int result = ps.executeUpdate();
		if(result <= 0) {
			throw new Exception("update sql result is zero: " + sql);
		}
		
		conn.rollback();
		ps.close();
		
		sql = "SELECT cust_name FROM customer WHERE cust_nbr=0";
		Statement stmt = conn.createStatement();
		ResultSet rs = stmt.executeQuery(sql);
		if(!rs.next()) {
			throw new Exception("query result is empty: " + sql);
		}
		
		String dbval = rs.getString(1);
		if(StringUtils.equalsIgnoreCase(StringUtils.trim(dbval), StringUtils.trim(value))) {
			throw new Exception("rollback failed");
		} else {
			logger.info("rollback success, update value: " + value + ", current DB value: " + dbval);
		}
		
		rs.close();
		conn.close();
	}

}
